from setuptools import setup

with open("README.md", "r") as fn:
    long_desc = fn.read()

setup(
    name = 'acesql',
    version = '0.1.6',
    description = 'Access to ACE Databases',
    py_modules = ["acesql"],
    package_dir = {'': 'src'},
    classifiers = [
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "License :: OSI Approved :: GNU General Public License v2 or later (GPLv2+)",
        "Operating System :: OS Independent",
    ],
    long_description = long_desc,
    long_description_content_type="text/markdown",
    install_requires = [
        "pyspark ~= 3.1.2"
    ],
    url="https://git.sonova.com/ACE/acedbpp.git",
    author="Cem Bakar",
    author_email="cem.bakar@sonova.com",
)



from pyspark.context import SparkContext
from pyspark.sql import SparkSession

## Parameters
# df: spark dataframe which cantains the data
# url: jdbc url - i.e: jdbc:sqlserver://url:portnumber
# database: Name of the database to write - i.e.: ace-db
# dbtable: schema and abd the name of the table - i.e.: dbo.dbs
# username: Username of the database
# password: Password of the user
def writeSQL(df, url, database, dbtable, username, password):
  r = df.write.mode("append") \
      .format("jdbc") \
      .option("url", url) \
      .option("database", database) \
      .option("dbtable", dbtable) \
      .option("user", username) \
      .option("password", password) \
      .save()
  return r

# url: jdbc url - i.e: jdbc:sqlserver://url:portnumber
# database: Name of the database to write - i.e.: ace-db
# dbtable: schema and abd the name of the table - i.e.: dbo.dbs
# username: Username of the database
# password: Password of the user
def readSQL(url, database, dbtable, username, password):
  spark = SparkSession \
    .builder \
    .appName("ACE Python Spark SQL Connecter") \
    .config("spark.some.config.option", "ACE") \
    .getOrCreate()

  r = spark.read \
    .format("jdbc") \
    .option("url", url) \
    .option("database", database) \
    .option("dbtable", dbtable) \
    .option("user", username) \
    .option("password", password) \
    .load()
  return r